@@ -1,4 +1,3 @@
-#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 """
@@ -31,7 +30,7 @@ from GoogleScraper.proxies import parse_proxy_file, get_proxies_from_mysql_db
 from GoogleScraper.res import maybe_create_db
 from GoogleScraper.scraping import SelScraper, GoogleScrape
 from GoogleScraper.caching import *
-from GoogleScraper.config import get_config, InvalidConfigurationException
+from GoogleScraper.config import get_config, InvalidConfigurationException, parse_cmd_args, Config
 import GoogleScraper.config
 
 try:
@@ -53,7 +52,6 @@ except ImportError as ie:
     sys.exit('You can install missing modules with `pip3 install [modulename]`')
 
 logger = logging.getLogger('GoogleScraper')
-Config = get_config(False)
 
 def deep_scrape(query):
     """Launches many different Google searches with different parameter combinations to maximize return of results. Depth first.
@@ -115,7 +113,7 @@ def scrape(keyword='', scrapemethod='sel', num_results_per_page=10, num_pages=1,
         return threads[0].results
 
 def scrape_with_config(config, **kwargs):
-    """First updates the global scrape configuration with the provided dictionary.
+    """First updates the global GoogleScraper configuration with the provided dictionary.
 
     Arguments:
     config -- A configuration dictionary that updates the global configuration.
@@ -182,7 +180,7 @@ def print_scrape_results_http(results, verbosity=1):
     """Print the results obtained by "http" method."""
     for t in results:
         for result in t:
-            logger.info('{} links found! The search with the keyword "{}" yielded the result:{}'.format(
+            logger.info('{} links found. The search with the keyword "{}" yielded the result: "{}"'.format(
                 len(result['results']), result['search_keyword'], result['num_results_for_kw']))
             import textwrap
             for result_set in ('results', 'ads_main', 'ads_aside'):
@@ -202,14 +200,13 @@ def print_scrape_results_http(results, verbosity=1):
                             print('*' * 70)
                             print()
 
-def main(return_results=True, force_reload=True, proxies=[]):
+def main(return_results=True, force_reload=False, proxies=[]):
     """Runs the GoogleScraper application as determined by the various configuration points.
 
     Keyword arguments:
     return_results -- Whether the GoogleScraper application is run programmatically. Will return all scraped results.
     """
-    global Config
-    Config = get_config(True, force_reload)
+    parse_cmd_args()
 
     if Config['GLOBAL'].getboolean('view_config'):
         from GoogleScraper.config import CONFIG_FILE
