@@ -31,14 +31,13 @@ except ImportError as ie:
 
 import GoogleScraper.socks as socks
 from GoogleScraper.caching import get_cached, cache_results, cached_file_name
-from GoogleScraper.config import get_config
+from GoogleScraper.config import Config
 from GoogleScraper.parsing import GoogleParser
 import GoogleScraper.google_search_params
 import webbrowser
 import tempfile
 
 logger = logging.getLogger('GoogleScraper')
-Config = get_config()
 
 class GoogleSearchError(Exception):
     pass
@@ -186,7 +185,7 @@ class GoogleScrape():
     def _build_query(self, rand=False):
         """Build the headers and params for the GET request for the Google server.
 
-        When random is True, several headers (like the UA) are chosen
+        If random is True, several headers (like the UA) are chosen
         randomly.
 
         There are currently four different Google searches supported:
@@ -290,6 +289,15 @@ class GoogleScrape():
 
         if not html:
             try:
+                base_url=Config['GLOBAL'].get('base_search_url')
+
+                if Config['GLOBAL'].getint('verbosity', 0) > 1:
+                    logger.info('[HTTP] Base_url: {base_url}, headers={headers}, params={params}'.format(
+                        base_url=base_url,
+                        headers=self._HEADERS,
+                        params=self.search_params
+                    ))
+
                 r = self.requests.get(Config['GLOBAL'].get('base_search_url'), headers=self._HEADERS,
                                  params=self.search_params, timeout=3.0)
 
